==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/gf/db/firebird/sql/install/01_TABLE/GF72S.sql <==
/****************************************************************************/
/* GF72 ( 登録ﾎﾞﾀﾝ状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2013/09/03 10:23:43                                            */
/****************************************************************************/
CREATE TABLE GF72 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (   1 )                 NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR ( 256 )                                     /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR (  60 )                                     /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR ( 256 )                                     /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR (  14 )                                     /*  60 最終更新日   */
 , TAGNAME      VARCHAR (  30 )                                     /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   VARCHAR (  30 )                                     /*  90 先画面ID     */
 , HREF         VARCHAR ( 256 )                                     /* 100 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR (  10 )                                     /* 110 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       VARCHAR ( 500 )                                     /* 120 引数ｷｰ       */
 , P_VALS       VARCHAR ( 500 )                                     /* 130 引数値       */
 , COMMAND      VARCHAR (  30 )                                     /* 140 ｺﾏﾝﾄﾞ        */
 , LBLCD        VARCHAR (  60 )                                     /* 150 ﾗﾍﾞﾙｺｰﾄﾞ     */
 , MSGCD        VARCHAR (  20 )                                     /* 160 ﾒｯｾｰｼﾞID     */
 , ONCLICK      VARCHAR ( 200 )                                     /* 170 ｲﾍﾞﾝﾄ        */
 , ROLES        VARCHAR ( 500 )                                     /* 180 ﾛｰﾙｽﾞ        */
 , FGOMIT       VARCHAR (   1 )     DEFAULT '0' NOT NULL            /* 190 除外ﾌﾗｸﾞ     */
 , UNIQ         BIGINT                          NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者       */
);

CREATE SEQUENCE GF72S00 ;

CREATE TRIGGER GF72T00 FOR GF72
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GF72S00,1 );
  END;

==> openGion_dev_5.6.9.0.zip: opengion/uap/webapps/gf/db/firebird/sql/install/01_TABLE/GF72S.sql <==
/****************************************************************************/
/* GF72 ( 登録ﾎﾞﾀﾝ状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2013/09/30 18:24:54                                            */
/****************************************************************************/
CREATE TABLE GF72 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (   1 )                 NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR ( 256 )                                     /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR (  60 )                                     /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR ( 256 )                                     /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR (  14 )                                     /*  60 最終更新日   */
 , TAGNAME      VARCHAR (  30 )                                     /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   VARCHAR (  30 )                                     /*  90 先画面ID     */
 , HREF         VARCHAR ( 256 )                                     /* 100 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR (  30 )                 NOT NULL            /* 110 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       VARCHAR ( 500 )                                     /* 120 引数ｷｰ       */
 , P_VALS       VARCHAR ( 500 )                                     /* 130 引数値       */
 , COMMAND      VARCHAR (  30 )                                     /* 140 ｺﾏﾝﾄﾞ        */
 , LBLCD        VARCHAR (  60 )                                     /* 150 ﾗﾍﾞﾙｺｰﾄﾞ     */
 , MSGCD        VARCHAR (  20 )                                     /* 160 ﾒｯｾｰｼﾞID     */
 , ONCLICK      VARCHAR ( 200 )                                     /* 170 ｲﾍﾞﾝﾄ        */
 , ROLES        VARCHAR ( 500 )                                     /* 180 ﾛｰﾙｽﾞ        */
 , FGOMIT       VARCHAR (   1 )     DEFAULT '0' NOT NULL            /* 190 除外ﾌﾗｸﾞ     */
 , UNIQ         BIGINT                          NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者       */
);

CREATE SEQUENCE GF72S00 ;

CREATE TRIGGER GF72T00 FOR GF72
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GF72S00,1 );
  END;
